@@ -14,14 +14,11 @@ service:
 #    host: 0.0.0.0
 #    port: 8080
 
-# Twitter service
+# Twitter sample stream service
 #service:
 #  name: msgflow.service.TwitterSampleStreamService
 #  config:
-#    consumer_key: ""
-#    consumer_secret: ""
-#    access_token_key: ""
-#    access_token_secret: ""
+#    bearer_token: ""
 #    lang: ja
 #    max_len: 50
 #    interval: 10
@@ -63,7 +60,7 @@ class MyApp:
         return cls()
 
     def handle(self, bot, msg):
-        log_msg = f'App got message: Message(text="{msg.text}", conversation_id="{msg.conversation_id}")'
+        log_msg = f'App got message: Message(text="{msg.text}", dialog_id="{msg.dialog_id}")'
         bot.post(log_msg)
         msg.respond(f'Thank you for your message "{msg.text}"!')
 """
