@@ -1,21 +1,19 @@
 from .cli_service import CliService
+from .twitter_service import TwitterSampleStreamService
+
+# from .twitter_mentions_timeline_service import TwitterMentionsTimelineService
 
 try:
     from .webapi_service import WebapiService
 except ImportError:
     pass
 
-try:
-    from .twitter_service import TwitterSampleStreamService
-except ImportError:
-    pass
-
-try:
-    from .twitter_mentions_timeline_service import TwitterMentionsTimelineService
-except ImportError:
-    pass
-
 try:
     from .slack_service import SlackService
 except ImportError:
     pass
+
+try:
+    from .cron_service import CronService
+except ImportError:
+    pass
