@@ -1,21 +1,35 @@
 from pydantic import BaseModel
 from fastapi import FastAPI
+from fastapi.middleware.cors import CORSMiddleware
 import uvicorn
+import pkg_resources
+from typing import Any
 
 
-def build_api(handler):
+def build_api(handler, endpoint):
+    def get_version():
+        pkg_name = "msgflow"
+        try:
+            version = pkg_resources.get_distribution(pkg_name).version
+        except pkg_resources.DistributionNotFound:
+            print(f"Package name not found: {pkg_name}")
+            version = "package version info not found"
+        return version
+
     app = FastAPI(
         title="msgFlow",
         description="",
-        version="0.0.0",
+        version=get_version(),
     )
-    app.add_api_route("/handle", handler.handle, methods=["POST"])
+    app.add_api_route(endpoint, handler.handle, methods=["POST"])
+
     return app
 
 
 class Request(BaseModel):
     text: str
-    conversation_id: str = 0
+    dialog_id: str = 0
+    data: dict[str, Any] = None
 
 
 class Response(BaseModel):
@@ -28,16 +42,17 @@ class Handler:
         self._bot = bot
 
     def handle(self, req: Request):
-        msg = WebapiMessage(text=req.text, conversation_id=req.conversation_id)
+        msg = WebapiMessage(text=req.text, dialog_id=req.dialog_id, req=req)
         self._bot.handle(msg)
         return Response(texts=msg.msgs, request=req)
 
 
 class WebapiMessage:
-    def __init__(self, text: str, conversation_id: str):
+    def __init__(self, text: str, dialog_id: str, req):
         """"""
         self._text = text
-        self._cid = conversation_id
+        self._cid = dialog_id
+        self._req = req
         self._msgs = []
 
     @property
@@ -45,13 +60,17 @@ class WebapiMessage:
         return self._text
 
     @property
-    def conversation_id(self) -> str:
+    def dialog_id(self) -> str:
         # In CliService, a conversation is identified by the user's name
         return self._cid
 
     def respond(self, text):
         self._msgs.append(text)
 
+    @property
+    def source(self) -> Any:
+        return self._req
+
     @property
     def msgs(self):
         return self._msgs
@@ -73,7 +92,10 @@ class WebapiService:
 
     def flow(self, bot):
         handler = Handler(bot=bot)
-        app = build_api(handler)
+        app = build_api(
+            handler,
+            endpoint=self._config.endpoint,
+        )
         uvicorn.run(app=app, host=self._config.host, port=self._config.port)
 
     def post(self, text):
@@ -83,3 +105,4 @@ class WebapiService:
 class WebapiConfig(BaseModel):
     host: str
     port: int
+    endpoint: str = "/handle"
